Objectives
==========

-  To further explore and expand a number of the ideas presented
   earlier.

-  To be able to implement a linked list.

-  To understand the RSA algorithm for public key encryption using some
   recursive mathematical functions.

-  To understand the expected behavior of a skip list as an alternative
   implementation for dictionaries.

-  To understand octrees and their use in image processing.

-  To understand string-matching as a graph problem.
